@@ -2,11 +2,13 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 
 from datetime import date
 from dateutil.parser import parse
+import re
 import sys
 import uuid
 
 from amaascore.assets.children import Link
 from amaascore.core.amaas_model import AMaaSModel
+from amaascore.core.comment import Comment
 from amaascore.core.reference import Reference
 
 # This extremely ugly hack is due to the whole Python 2 vs 3 debacle.
@@ -17,16 +19,19 @@ class Asset(AMaaSModel):
 
     @staticmethod
     def children():
-        return {'links': Link, 'references': Reference}
+        return {'comments': Comment, 'links': Link, 'references': Reference}
 
     def __init__(self, asset_manager_id, fungible, asset_issuer_id=None, asset_id=None, asset_status='Active',
-                 country_id=None, venue_id=None, currency=None, issue_date=date.min, maturity_date=date.max,
-                 description='', links=None, references=None, client_additional=None,
+                 country_id=None, venue_id=None, currency=None, issue_date=date.min,
+                 roll_price=True, display_name='', description='',
+                 comments=None, links=None, references=None, client_additional=None,
                  *args, **kwargs):
         self.asset_manager_id = asset_manager_id
         self.asset_id = asset_id or uuid.uuid4().hex
         if not hasattr(self, 'asset_class'):  # A more specific child class may have already set this
             self.asset_class = 'Asset'
+        # This can be overridden if necessary but I think it probably shouldn't
+        self.asset_type_display = ' '.join(re.findall('[A-Z][^A-Z]*', self.__class__.__name__))
         self.asset_type = self.__class__.__name__
         self.fungible = fungible
         self.asset_issuer_id = asset_issuer_id
@@ -35,14 +40,15 @@ class Asset(AMaaSModel):
         self.venue_id = venue_id
         self.currency = currency
         self.issue_date = issue_date
-        self.maturity_date = maturity_date
+        self.roll_price = roll_price
+        self.display_name = display_name
         self.description = description
         self.client_additional = client_additional  # A field to allow people to build their own assets
         # Defaults are here not in constructor for mutability reasons.
-        self.links = links or {}
-        self.references = references or {}
+        self.comments = comments.copy() if comments else {}
+        self.links = links.copy() if links else {}
+        self.references = references.copy() if references else {}
         self.references['AMaaS'] = Reference(reference_value=self.asset_id)  # Upserts the AMaaS Reference
-
         super(Asset, self).__init__(*args, **kwargs)
 
     def reference_types(self):
@@ -84,3 +90,20 @@ class Asset(AMaaSModel):
 
     def __str__(self):
         return "Asset object - ID: %s" % self.asset_id
+
+    def get_country_codes(self):
+        return [self.country_id]
+
+    def country_and_venue_codes(self):
+        """
+        This function returns dictionary in the format of {"country_codes": [XYZ, ABC], "venue_id": [ABC]} 
+        Where country_codes = self.country_id and venue_id = self.venue_id
+        except for FX where we also return the country_ids associated with the legs of the FX transaction 
+        (e.g. USDJPY returns USA + JPN).
+        """
+        codes = {'country_codes': self.get_country_codes(), 'venue_id': [self.venue_id]}
+        return codes
+        
+    def get_currencies(self):
+        return [self.currency]
+
