@@ -10,3 +10,11 @@ class Link(AMaaSModel):
         self.active = active
         self.version = version
         super(Link, self).__init__(*args, **kwargs)
+
+class Reference(AMaaSModel):
+
+    def __init__(self, reference_value, active=True, *args, **kwargs):
+        self.reference_value = reference_value
+        self.active = active
+        super(Reference, self).__init__(*args, **kwargs)
+        
\ No newline at end of file
