@@ -9,6 +9,7 @@ from amaascore.assets.bond import BondCorporate, BondGovernment, BondMortgage
 from amaascore.assets.bond_future import BondFuture
 from amaascore.assets.bond_future_option import BondFutureOption
 from amaascore.assets.bond_option import BondOption
+from amaascore.assets.commodity_future import CommodityFuture
 from amaascore.assets.cfd import ContractForDifference
 from amaascore.assets.currency import Currency
 from amaascore.assets.custom_asset import CustomAsset
@@ -20,6 +21,7 @@ from amaascore.assets.foreign_exchange import ForeignExchange, NonDeliverableFor
 from amaascore.assets.fund import Fund
 from amaascore.assets.future import Future
 from amaascore.assets.future_option import FutureOption
+from amaascore.assets.fx_future import ForeignExchangeFuture
 from amaascore.assets.fx_option import ForeignExchangeOption
 from amaascore.assets.index import Index
 from amaascore.assets.index_future import IndexFuture
@@ -32,7 +34,10 @@ from amaascore.assets.sukuk import Sukuk
 from amaascore.assets.synthetic import Synthetic
 from amaascore.assets.synthetic_from_book import SyntheticFromBook
 from amaascore.assets.synthetic_multi_leg import SyntheticMultiLeg
-
+from amaascore.assets.wine import Wine
+from amaascore.assets.automobile import Automobile
+from amaascore.assets.warrants import Warrant
+from amaascore.assets.private_investment import PrivateInvestment
 
 def json_to_asset(json_asset):
     # Iterate through the asset children, converting the various JSON attributes into the relevant class type
@@ -50,6 +55,8 @@ def json_to_asset(json_asset):
             collection[child_type] = child
         json_asset[collection_name] = collection
     clazz = globals().get(json_asset.get('asset_type'))
+    if not clazz:
+        raise ValueError('Missing Asset Type: %s' % json_asset.get('asset_type'))
     args = inspect.getargspec(clazz.__init__)
     # Some fields are always added in, even though they're not explicitly part of the constructor
     clazz_args = args.args + clazz.amaas_model_attributes()
