@@ -3,16 +3,16 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 import logging
 
 from amaascore.books.utils import json_to_book
-from amaascore.config import ENDPOINTS
+from amaascore.config import ENVIRONMENT
 from amaascore.core.interface import Interface
 
 
 class BooksInterface(Interface):
 
-    def __init__(self, logger=None):
-        endpoint = ENDPOINTS.get('books')
-        self.logger = logger or logging.getLogger(__name__)
-        super(BooksInterface, self).__init__(endpoint=endpoint)
+    def __init__(self, environment=ENVIRONMENT, logger=None, endpoint=None, username=None, password=None):
+        logger = logger or logging.getLogger(__name__)
+        super(BooksInterface, self).__init__(endpoint=endpoint, endpoint_type='books', environment=environment,
+                                             username=username, password=password, logger=logger)
 
     def new(self, book):
         self.logger.info('New Book - Asset Manager: %s - Book ID: %s', book.asset_manager_id, book.book_id)
@@ -40,9 +40,11 @@ class BooksInterface(Interface):
             self.logger.error(response.text)
             response.raise_for_status()
 
-    def retrieve(self, asset_manager_id, book_id):
+    def retrieve(self, asset_manager_id, book_id, version=None):
         self.logger.info('Retrieve Book - Asset Manager: %s - Book ID: %s', asset_manager_id, book_id)
         url = '%s/books/%s/%s' % (self.endpoint, asset_manager_id, book_id)
+        if version:
+            url += '?version=%d' % int(version)
         response = self.session.get(url)
         if response.ok:
             self.logger.info('Successfully Retrieved Book - Asset Manager: %s - Book ID: %s', asset_manager_id,
@@ -69,20 +71,21 @@ class BooksInterface(Interface):
         search_params = {}
         # Potentially roll this into a loop through args rather than explicitly named - depends on additional validation
         if asset_manager_ids:
-            search_params['asset_manager_ids'] = asset_manager_ids
+            search_params['asset_manager_ids'] = ','.join([str(amid) for amid in asset_manager_ids])
         if book_ids:
-            search_params['book_ids'] = book_ids
+            search_params['book_ids'] = ','.join(book_ids)
         if business_units:
-            search_params['business_units'] = business_units
+            search_params['business_units'] = ','.join(business_units)
         if owner_ids:
-            search_params['owner_ids'] = owner_ids
+            search_params['owner_ids'] = ','.join(owner_ids)
         if party_ids:
-            search_params['party_ids'] = party_ids
+            search_params['party_ids'] = ','.join(party_ids)
         url = self.endpoint + '/books'
         response = self.session.get(url, params=search_params)
         if response.ok:
-            books = [json_to_book(json_book) for json_book in response.json()]
-            self.logger.info('Returned %s Books.', len(books))
+            books = [json_to_book(json_book)
+                     for json_book in response.json()] if response.json() else None
+            self.logger.info('Returned %s Books.', len(books) if books else 0)
             return books
         else:
             self.logger.error(response.text)
@@ -111,3 +114,18 @@ class BooksInterface(Interface):
         else:
             self.logger.error(response.text)
             response.raise_for_status()
+
+    def clear(self, asset_manager_id):
+        """ This method deletes all the data for an asset_manager_id.
+            It should be used with extreme caution.  In production it
+            is almost always better to Retire rather than delete. """
+        self.logger.info('Clear Books - Asset Manager: %s', asset_manager_id)
+        url = '%s/clear/%s' % (self.endpoint, asset_manager_id)
+        response = self.session.delete(url)
+        if response.ok:
+            count = response.json().get('count', 'Unknown')
+            self.logger.info('Deleted %s Books.', count)
+            return count
+        else:
+            self.logger.error(response.text)
+            response.raise_for_status()
