@@ -3,7 +3,7 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 import json
 import logging
 
-from amaascore.config import ENDPOINTS
+from amaascore.config import ENVIRONMENT
 from amaascore.core.amaas_model import json_handler
 from amaascore.core.interface import Interface
 from amaascore.parties.utils import json_to_party
@@ -11,10 +11,13 @@ from amaascore.parties.utils import json_to_party
 
 class PartiesInterface(Interface):
 
-    def __init__(self, logger=None):
-        endpoint = ENDPOINTS.get('parties')
+    def __init__(self, environment=ENVIRONMENT, logger=None, endpoint=None, username=None, password=None):
         self.logger = logger or logging.getLogger(__name__)
-        super(PartiesInterface, self).__init__(endpoint=endpoint)
+        super(PartiesInterface, self).__init__(endpoint=endpoint, 
+                                               endpoint_type='parties', 
+                                               environment=environment, 
+                                               username=None, 
+                                               password=None)
 
     def new(self, party):
         self.logger.info('New Party - Asset Manager: %s - Party ID: %s', party.asset_manager_id, party.party_id)
@@ -51,9 +54,11 @@ class PartiesInterface(Interface):
             self.logger.error(response.text)
             response.raise_for_status()
 
-    def retrieve(self, asset_manager_id, party_id):
+    def retrieve(self, asset_manager_id, party_id, version=None):
         self.logger.info('Retrieve Party - Asset Manager: %s - Party ID: %s', asset_manager_id, party_id)
         url = '%s/parties/%s/%s' % (self.endpoint, asset_manager_id, party_id)
+        if version:
+            url += '?version=%d' % int(version)
         response = self.session.get(url)
         if response.ok:
             return json_to_party(response.json())
@@ -77,9 +82,9 @@ class PartiesInterface(Interface):
         search_params = {}
         # Potentially roll this into a loop through args rather than explicitly named - depends on additional validation
         if asset_manager_ids:
-            search_params['asset_manager_ids'] = asset_manager_ids
+            search_params['asset_manager_ids'] = ','.join([str(amid) for amid in asset_manager_ids])
         if party_ids:
-            search_params['party_ids'] = party_ids
+            search_params['party_ids'] = ','.join(party_ids)
         url = self.endpoint + '/parties'
         response = self.session.get(url, params=search_params)
         if response.ok:
@@ -101,3 +106,18 @@ class PartiesInterface(Interface):
         else:
             self.logger.error(response.text)
             response.raise_for_status()
+
+    def clear(self, asset_manager_id):
+        """ This method deletes all the data for an asset_manager_id.
+            It should be used with extreme caution.  In production it
+            is almost always better to Inactivate rather than delete. """
+        self.logger.info('Clear Parties - Asset Manager: %s', asset_manager_id)
+        url = '%s/clear/%s' % (self.endpoint, asset_manager_id)
+        response = self.session.delete(url)
+        if response.ok:
+            count = response.json().get('count', 'Unknown')
+            self.logger.info('Deleted %s Parties.', count)
+            return count
+        else:
+            self.logger.error(response.text)
+            response.raise_for_status()
