@@ -3,7 +3,7 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 import logging
 import json
 
-from amaascore.config import ENDPOINTS
+from amaascore.config import ENVIRONMENT
 from amaascore.core.amaas_model import json_handler
 from amaascore.core.interface import Interface
 from amaascore.transactions.utils import json_to_transaction, json_to_position
@@ -11,15 +11,15 @@ from amaascore.transactions.utils import json_to_transaction, json_to_position
 
 class TransactionsInterface(Interface):
 
-    def __init__(self, logger=None):
-        endpoint = ENDPOINTS.get('transactions')
+    def __init__(self, environment=ENVIRONMENT, logger=None, endpoint=None, username=None, password=None):
         self.logger = logger or logging.getLogger(__name__)
-        super(TransactionsInterface, self).__init__(endpoint=endpoint)
+        super(TransactionsInterface, self).__init__(endpoint=endpoint, endpoint_type='transactions',
+                                                    environment=environment, username=None, password=None)
 
     def new(self, transaction):
         self.logger.info('New Transaction - Asset Manager: %s - Transaction ID: %s', transaction.asset_manager_id,
                          transaction.transaction_id)
-        url = self.endpoint + '/transactions'
+        url = '%s/transactions/%s' % (self.endpoint, transaction.asset_manager_id)
         response = self.session.post(url, json=transaction.to_interface())
         if response.ok:
             transaction = json_to_transaction(response.json())
@@ -52,10 +52,12 @@ class TransactionsInterface(Interface):
             self.logger.error(response.text)
             response.raise_for_status()
 
-    def retrieve(self, asset_manager_id, transaction_id):
+    def retrieve(self, asset_manager_id, transaction_id, version=None):
         self.logger.info('Retrieve Transaction - Asset Manager: %s - Transaction ID: %s', asset_manager_id,
                          transaction_id)
         url = '%s/transactions/%s/%s' % (self.endpoint, asset_manager_id, transaction_id)
+        if version:
+            url += '?version=%d' % int(version)
         response = self.session.get(url)
         if response.ok:
             return json_to_transaction(response.json())
@@ -95,39 +97,39 @@ class TransactionsInterface(Interface):
         search_params = {}
         # Potentially roll this into a loop through args rather than explicitly named - depends on additional validation
         if asset_manager_ids:
-            search_params['asset_manager_ids'] = asset_manager_ids
+            search_params['asset_manager_ids'] = ','.join([str(amid) for amid in asset_manager_ids])
         if transaction_ids:
-            search_params['transaction_ids'] = transaction_ids
+            search_params['transaction_ids'] = ','.join(transaction_ids)
         if transaction_statuses:
-            search_params['transaction_statuses'] = transaction_statuses
+            search_params['transaction_statuses'] = ','.join(transaction_statuses)
         if asset_book_ids:
-            search_params['asset_book_ids'] = asset_book_ids
+            search_params['asset_book_ids'] = ','.join(asset_book_ids)
         if counterparty_book_ids:
-            search_params['counterparty_book_ids'] = counterparty_book_ids
+            search_params['counterparty_book_ids'] = ','.join(counterparty_book_ids)
         if asset_ids:
-            search_params['asset_ids'] = asset_ids
+            search_params['asset_ids'] = ','.join(asset_ids)
         if transaction_date_start:
             search_params['transaction_date_start'] = transaction_date_start
         if transaction_date_end:
             search_params['transaction_date_end'] = transaction_date_end
         if code_types:
-            search_params['code_types'] = code_types
+            search_params['code_types'] = ','.join(code_types)
         if code_values:
-            search_params['code_values'] = code_values
+            search_params['code_values'] = ','.join(code_values)
         if link_types:
-            search_params['link_types'] = link_types
+            search_params['link_types'] = ','.join(link_types)
         if linked_transaction_ids:
-            search_params['linked_transaction_ids'] = linked_transaction_ids
+            search_params['linked_transaction_ids'] = ','.join(linked_transaction_ids)
         if party_types:
-            search_params['party_types'] = party_types
+            search_params['party_types'] = ','.join(party_types)
         if party_ids:
-            search_params['party_ids'] = party_ids
+            search_params['party_ids'] = ','.join(party_ids)
         if reference_types:
-            search_params['reference_types'] = reference_types
+            search_params['reference_types'] = ','.join(reference_types)
         if reference_values:
-            search_params['reference_values'] = reference_values
+            search_params['reference_values'] = ','.join(reference_values)
         if client_ids:
-            search_params['client_ids'] = client_ids
+            search_params['client_ids'] = ','.join(client_ids)
         url = self.endpoint + '/transactions'
         response = self.session.get(url, params=search_params)
         if response.ok:
@@ -145,15 +147,15 @@ class TransactionsInterface(Interface):
         search_params = {}
         # Potentially roll into a loop
         if asset_manager_ids:
-            search_params['asset_manager_ids'] = asset_manager_ids
+            search_params['asset_manager_ids'] = ','.join([str(amid) for amid in asset_manager_ids])
         if book_ids:
-            search_params['book_ids'] = book_ids
+            search_params['book_ids'] = ','.join(book_ids)
         if account_ids:
-            search_params['account_ids'] = account_ids
+            search_params['account_ids'] = ','.join(account_ids)
         if accounting_types:
-            search_params['accounting_types'] = accounting_types
+            search_params['accounting_types'] = ','.join(accounting_types)
         if asset_ids:
-            search_params['asset_ids'] = asset_ids
+            search_params['asset_ids'] = ','.join(asset_ids)
         if position_date:
             search_params['position_date'] = position_date
         response = self.session.get(url, params=search_params)
@@ -165,6 +167,7 @@ class TransactionsInterface(Interface):
             self.logger.error(response.text)
             response.raise_for_status()
 
+    # Should this method just be collapsed into positions_by_asset_manager?
     def positions_by_asset_manager_book(self, asset_manager_id, book_id):
         self.logger.info('Retrieve Positions by Asset Manager: %s and Book: %s', asset_manager_id, book_id)
         url = '%s/positions/%s/%s' % (self.endpoint, asset_manager_id, book_id)
@@ -177,10 +180,11 @@ class TransactionsInterface(Interface):
             self.logger.error(response.text)
             response.raise_for_status()
 
-    def positions_by_asset_manager(self, asset_manager_id):
+    def positions_by_asset_manager(self, asset_manager_id, book_ids=None):
         self.logger.info('Retrieve Positions by Asset Manager: %s', asset_manager_id)
         url = '%s/positions/%s' % (self.endpoint, asset_manager_id)
-        response = self.session.get(url)
+        params = {'book_ids': ','.join(book_ids)} if book_ids else {}
+        response = self.session.get(url, params=params)
         if response.ok:
             positions = [json_to_position(json_position) for json_position in response.json()]
             self.logger.info('Returned %s Positions.', len(positions))
@@ -337,3 +341,22 @@ class TransactionsInterface(Interface):
                                   book transfer, except it requires an external message to a
                                   custodian to instruct them to move the stock to a
                                    different depot account.""")
+
+    def clear(self, asset_manager_id, book_ids=None):
+        """ This method deletes all the data for an asset_manager_id
+            and option book_ids.
+            It should be used with extreme caution.  In production it
+            is almost always better to Inactivate rather than delete. """
+        self.logger.info('Clear Transactions & Positions - Asset Manager: %s', asset_manager_id)
+        url = '%s/clear/%s' % (self.endpoint, asset_manager_id)
+        params = {'asset_manager_ids': ','.join(book_ids)} if book_ids else {}
+        response = self.session.delete(url, params=params)
+        if response.ok:
+            tran_count = response.json().get('transaction_count', 'Unknown')
+            self.logger.info('Deleted %s Transactions.', tran_count)
+            pos_count = response.json().get('position_count', 'Unknown')
+            self.logger.info('Deleted %s Positions.', pos_count)
+            return response.json()
+        else:
+            self.logger.error(response.text)
+            response.raise_for_status()
